Enum network::peer_manager::builder::AuthenticationMode [−][src]
pub enum AuthenticationMode {
MaybeMutual(PrivateKey),
Mutual(PrivateKey),
}Expand description
Inbound and Outbound connections are always secured with NoiseIK. The dialer will always verify the listener.
Variants
MaybeMutual(PrivateKey)Inbound connections will first be checked against the known peers set, and
if the PeerId is known it will be authenticated against it’s PublicKey
Otherwise, the incoming connections will be allowed through in the common
pool of unknown peers.
Tuple Fields of MaybeMutual
0: PrivateKeyMutual(PrivateKey)Both dialer and listener will verify public keys of each other in the handshake.
Tuple Fields of Mutual
0: PrivateKeyTrait Implementations